@@ -70,13 +70,13 @@ KPriMaApp::KPriMaApp()
 	_toolDir = _dataDir + (QString) "/tools";
 	
 	// add _toolDir to PATH
-	QString path = (QString) getenv("PATH");
-	path += (QString) ":" + _toolDir + (QString) ":";
-	debug("PATH=%s",path.data());
-	if (setenv("PATH", path.data(),1) == 0)
-		debug("setenv ok");
-	else
-		debug("setenv error");
+	//QString path = (QString) getenv("PATH");
+	//path += (QString) ":" + _toolDir + (QString) ":";
+	//debug("PATH=%s",path.data());
+	//if (setenv("PATH", path.data(),1) == 0)
+	//	debug("setenv ok");
+	//else
+	//	debug("setenv error");
 }
 
 KPriMaApp::~KPriMaApp()
@@ -103,10 +103,10 @@ void KPriMaApp::connectWidgets()
 	connect(&about, SIGNAL(openURL(const char*)),
 					this, SLOT(slotOpenURL(const char*)));
 					
-	connect(&process,SIGNAL(receivedStdout(KProcess *,char *,int)),
-					logViewer,SLOT(slotGotData(KProcess *,char *,int)));
-	connect(&process,SIGNAL(receivedStderr(KProcess *,char *,int)),
-					logViewer,SLOT(slotGotData(KProcess *,char *,int)));
+//	connect(&process,SIGNAL(receivedStdout(KProcess *,char *,int)),
+//					logViewer,SLOT(slotGotData(KProcess *,char *,int)));
+//	connect(&process,SIGNAL(receivedStderr(KProcess *,char *,int)),
+//					logViewer,SLOT(slotGotData(KProcess *,char *,int)));
 
 }
 
@@ -140,7 +140,7 @@ void KPriMaApp::initMenuBar()
   file_menu->insertSeparator();
   file_menu->insertItem(Icon("filefloppy.xpm") ,i18n("Save &as..."), ID_FILE_SAVE_AS );
   file_menu->insertSeparator();
-  file_menu->insertItem(i18n("Pre&view"), ID_FILE_PREVIEW );
+  file_menu->insertItem(i18n("Previe&w"), ID_FILE_PREVIEW );
   file_menu->insertItem(Icon("fileprint.xpm"), i18n("&Print"), ID_FILE_PRINT );
   file_menu->insertSeparator();
   file_menu->insertItem(i18n("E&xit"), ID_FILE_QUIT );
@@ -441,7 +441,9 @@ void KPriMaApp::slotFilePreview()
 
   int error = 0;
   QString command;
-  QString file = _settings->getWorkFile();
+	PrinterEntry *entry = _settings->getPrinterEntry();
+  QString 			file 	= _settings->getWorkFile();
+	QString 			c 	 	= entry->previewCommand;
 
   if (file.isEmpty())
   {
@@ -471,7 +473,16 @@ void KPriMaApp::slotFilePreview()
   		return;
   	}
 
-  command.sprintf(_PS_Viewer.data(),_TargetFileTransfer.data());
+	if (_TargetFileTransfer.isEmpty())
+		return;
+		
+	// find %PSFILE and substitute it with the
+	// chosen file and a temporar name for the PSFILE
+	command = substituteInFilePSFile(c,0,_TargetFileTransfer);
+	if (command.isEmpty())
+		return;
+  	
+  // command.sprintf(_PS_Viewer.data(),_TargetFileTransfer.data());
 
   if ((error = executeCommand(command,KProcess::DontCare)) != 0)
   {
@@ -743,9 +754,16 @@ int KPriMaApp::transformFile()
 int KPriMaApp::executeCommand(const QString &command,
 															KProcess::RunMode rm)
 {
+ 	KShellProcess	process;
+ 	
   bool success       	= false;
 
- 	// now spawn process
+	connect(&process,SIGNAL(receivedStdout(KProcess *,char *,int)),
+					logViewer,SLOT(slotGotData(KProcess *,char *,int)));
+	connect(&process,SIGNAL(receivedStderr(KProcess *,char *,int)),
+					logViewer,SLOT(slotGotData(KProcess *,char *,int)));
+
+  // now spawn process
  	process.clearArguments();
   debug("execute: %s",command.data());
  	process << command.data();
